==> onos-yang-runtime-2.2.0-sources.jar: org/onosproject/yang/gen/v1/l3vpnsvcext/rev20160730/l3vpnsvcext/bgpprofile/DefaultBgpTimer.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.l3vpnsvcext.rev20160730.l3vpnsvcext.bgpprofile;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of bgpTimer.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultBgpTimer extends InnerModelObject implements BgpTimer {
    protected int keepAlive;
    protected int holdTime;
    protected BitSet valueLeafFlags = new BitSet();

    @Override
    public int keepAlive() {
        return keepAlive;
    }

    @Override
    public int holdTime() {
        return holdTime;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public void keepAlive(int keepAlive) {
        valueLeafFlags.set(LeafIdentifier.KEEPALIVE.getLeafIndex());
        this.keepAlive = keepAlive;
    }

    @Override
    public void holdTime(int holdTime) {
        valueLeafFlags.set(LeafIdentifier.HOLDTIME.getLeafIndex());
        this.holdTime = holdTime;
    }

    @Override
    public int hashCode() {
        return Objects.hash(keepAlive, holdTime, valueLeafFlags);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultBgpTimer) {
            DefaultBgpTimer other = (DefaultBgpTimer) obj;
            return
                Objects.equals(keepAlive, other.keepAlive) &&
                Objects.equals(holdTime, other.holdTime) &&
                Objects.equals(valueLeafFlags, other.valueLeafFlags);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("keepAlive=" + keepAlive)
            .add("holdTime=" + holdTime)
            .add("valueLeafFlags=" + valueLeafFlags)
            .toString();
    }


    /**
     * Creates an instance of defaultBgpTimer.
     */
    public DefaultBgpTimer() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/l3vpnsvcext/rev20160730/l3vpnsvcext/bgpprofile/DefaultBgpTimer.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.l3vpnsvcext.rev20160730.l3vpnsvcext.bgpprofile;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of bgpTimer.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultBgpTimer extends InnerModelObject implements BgpTimer {
    protected int keepAlive;
    protected int holdTime;
    protected BitSet valueLeafFlags = new BitSet();

    @Override
    public int keepAlive() {
        return keepAlive;
    }

    @Override
    public int holdTime() {
        return holdTime;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public void keepAlive(int keepAlive) {
        valueLeafFlags.set(LeafIdentifier.KEEPALIVE.getLeafIndex());
        this.keepAlive = keepAlive;
    }

    @Override
    public void holdTime(int holdTime) {
        valueLeafFlags.set(LeafIdentifier.HOLDTIME.getLeafIndex());
        this.holdTime = holdTime;
    }

    @Override
    public int hashCode() {
        return Objects.hash(keepAlive, holdTime, valueLeafFlags);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultBgpTimer) {
            DefaultBgpTimer other = (DefaultBgpTimer) obj;
            return
                Objects.deepEquals(keepAlive, other.keepAlive) &&
                Objects.deepEquals(holdTime, other.holdTime) &&
                Objects.deepEquals(valueLeafFlags, other.valueLeafFlags);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("keepAlive=" + keepAlive)
            .add("holdTime=" + holdTime)
            .add("valueLeafFlags=" + valueLeafFlags)
            .toString();
    }


    /**
     * Creates an instance of defaultBgpTimer.
     */
    public DefaultBgpTimer() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}
